stalker.ext.auth.authenticate — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.ext.auth.authenticate

static `auth.` `authenticate`(username='', password='')

  Authenticates the given username and password, returns a stalker.core.models.User object

  There needs to be a already setup database for the authentication to hapen.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »